==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/Office365GroupsActivityCounts.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.time.LocalDate;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "reportRefreshDate", 
    "exchangeEmailsReceived", 
    "yammerMessagesPosted", 
    "yammerMessagesRead", 
    "yammerMessagesLiked", 
    "reportDate", 
    "reportPeriod"})
@JsonInclude(Include.NON_NULL)
public class Office365GroupsActivityCounts extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.office365GroupsActivityCounts";
    }

    @JsonProperty("reportRefreshDate")
    protected LocalDate reportRefreshDate;

    @JsonProperty("exchangeEmailsReceived")
    protected Long exchangeEmailsReceived;

    @JsonProperty("yammerMessagesPosted")
    protected Long yammerMessagesPosted;

    @JsonProperty("yammerMessagesRead")
    protected Long yammerMessagesRead;

    @JsonProperty("yammerMessagesLiked")
    protected Long yammerMessagesLiked;

    @JsonProperty("reportDate")
    protected LocalDate reportDate;

    @JsonProperty("reportPeriod")
    protected String reportPeriod;

    protected Office365GroupsActivityCounts() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderOffice365GroupsActivityCounts() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private LocalDate reportRefreshDate;
        private Long exchangeEmailsReceived;
        private Long yammerMessagesPosted;
        private Long yammerMessagesRead;
        private Long yammerMessagesLiked;
        private LocalDate reportDate;
        private String reportPeriod;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder reportRefreshDate(LocalDate reportRefreshDate) {
            this.reportRefreshDate = reportRefreshDate;
            this.changedFields = changedFields.add("reportRefreshDate");
            return this;
        }

        public Builder exchangeEmailsReceived(Long exchangeEmailsReceived) {
            this.exchangeEmailsReceived = exchangeEmailsReceived;
            this.changedFields = changedFields.add("exchangeEmailsReceived");
            return this;
        }

        public Builder yammerMessagesPosted(Long yammerMessagesPosted) {
            this.yammerMessagesPosted = yammerMessagesPosted;
            this.changedFields = changedFields.add("yammerMessagesPosted");
            return this;
        }

        public Builder yammerMessagesRead(Long yammerMessagesRead) {
            this.yammerMessagesRead = yammerMessagesRead;
            this.changedFields = changedFields.add("yammerMessagesRead");
            return this;
        }

        public Builder yammerMessagesLiked(Long yammerMessagesLiked) {
            this.yammerMessagesLiked = yammerMessagesLiked;
            this.changedFields = changedFields.add("yammerMessagesLiked");
            return this;
        }

        public Builder reportDate(LocalDate reportDate) {
            this.reportDate = reportDate;
            this.changedFields = changedFields.add("reportDate");
            return this;
        }

        public Builder reportPeriod(String reportPeriod) {
            this.reportPeriod = reportPeriod;
            this.changedFields = changedFields.add("reportPeriod");
            return this;
        }

        public Office365GroupsActivityCounts build() {
            Office365GroupsActivityCounts _x = new Office365GroupsActivityCounts();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.office365GroupsActivityCounts";
            _x.id = id;
            _x.reportRefreshDate = reportRefreshDate;
            _x.exchangeEmailsReceived = exchangeEmailsReceived;
            _x.yammerMessagesPosted = yammerMessagesPosted;
            _x.yammerMessagesRead = yammerMessagesRead;
            _x.yammerMessagesLiked = yammerMessagesLiked;
            _x.reportDate = reportDate;
            _x.reportPeriod = reportPeriod;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id.toString()));
        }
    }

    @Property(name="reportRefreshDate")
    @JsonIgnore
    public Optional<LocalDate> getReportRefreshDate() {
        return Optional.ofNullable(reportRefreshDate);
    }

    public Office365GroupsActivityCounts withReportRefreshDate(LocalDate reportRefreshDate) {
        Office365GroupsActivityCounts _x = _copy();
        _x.changedFields = changedFields.add("reportRefreshDate");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.office365GroupsActivityCounts");
        _x.reportRefreshDate = reportRefreshDate;
        return _x;
    }

    @Property(name="exchangeEmailsReceived")
    @JsonIgnore
    public Optional<Long> getExchangeEmailsReceived() {
        return Optional.ofNullable(exchangeEmailsReceived);
    }

    public Office365GroupsActivityCounts withExchangeEmailsReceived(Long exchangeEmailsReceived) {
        Office365GroupsActivityCounts _x = _copy();
        _x.changedFields = changedFields.add("exchangeEmailsReceived");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.office365GroupsActivityCounts");
        _x.exchangeEmailsReceived = exchangeEmailsReceived;
        return _x;
    }

    @Property(name="yammerMessagesPosted")
    @JsonIgnore
    public Optional<Long> getYammerMessagesPosted() {
        return Optional.ofNullable(yammerMessagesPosted);
    }

    public Office365GroupsActivityCounts withYammerMessagesPosted(Long yammerMessagesPosted) {
        Office365GroupsActivityCounts _x = _copy();
        _x.changedFields = changedFields.add("yammerMessagesPosted");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.office365GroupsActivityCounts");
        _x.yammerMessagesPosted = yammerMessagesPosted;
        return _x;
    }

    @Property(name="yammerMessagesRead")
    @JsonIgnore
    public Optional<Long> getYammerMessagesRead() {
        return Optional.ofNullable(yammerMessagesRead);
    }

    public Office365GroupsActivityCounts withYammerMessagesRead(Long yammerMessagesRead) {
        Office365GroupsActivityCounts _x = _copy();
        _x.changedFields = changedFields.add("yammerMessagesRead");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.office365GroupsActivityCounts");
        _x.yammerMessagesRead = yammerMessagesRead;
        return _x;
    }

    @Property(name="yammerMessagesLiked")
    @JsonIgnore
    public Optional<Long> getYammerMessagesLiked() {
        return Optional.ofNullable(yammerMessagesLiked);
    }

    public Office365GroupsActivityCounts withYammerMessagesLiked(Long yammerMessagesLiked) {
        Office365GroupsActivityCounts _x = _copy();
        _x.changedFields = changedFields.add("yammerMessagesLiked");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.office365GroupsActivityCounts");
        _x.yammerMessagesLiked = yammerMessagesLiked;
        return _x;
    }

    @Property(name="reportDate")
    @JsonIgnore
    public Optional<LocalDate> getReportDate() {
        return Optional.ofNullable(reportDate);
    }

    public Office365GroupsActivityCounts withReportDate(LocalDate reportDate) {
        Office365GroupsActivityCounts _x = _copy();
        _x.changedFields = changedFields.add("reportDate");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.office365GroupsActivityCounts");
        _x.reportDate = reportDate;
        return _x;
    }

    @Property(name="reportPeriod")
    @JsonIgnore
    public Optional<String> getReportPeriod() {
        return Optional.ofNullable(reportPeriod);
    }

    public Office365GroupsActivityCounts withReportPeriod(String reportPeriod) {
        Office365GroupsActivityCounts _x = _copy();
        _x.changedFields = changedFields.add("reportPeriod");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.office365GroupsActivityCounts");
        _x.reportPeriod = reportPeriod;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public Office365GroupsActivityCounts patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        Office365GroupsActivityCounts _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public Office365GroupsActivityCounts put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        Office365GroupsActivityCounts _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private Office365GroupsActivityCounts _copy() {
        Office365GroupsActivityCounts _x = new Office365GroupsActivityCounts();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.id = id;
        _x.reportRefreshDate = reportRefreshDate;
        _x.exchangeEmailsReceived = exchangeEmailsReceived;
        _x.yammerMessagesPosted = yammerMessagesPosted;
        _x.yammerMessagesRead = yammerMessagesRead;
        _x.yammerMessagesLiked = yammerMessagesLiked;
        _x.reportDate = reportDate;
        _x.reportPeriod = reportPeriod;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("Office365GroupsActivityCounts[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("reportRefreshDate=");
        b.append(this.reportRefreshDate);
        b.append(", ");
        b.append("exchangeEmailsReceived=");
        b.append(this.exchangeEmailsReceived);
        b.append(", ");
        b.append("yammerMessagesPosted=");
        b.append(this.yammerMessagesPosted);
        b.append(", ");
        b.append("yammerMessagesRead=");
        b.append(this.yammerMessagesRead);
        b.append(", ");
        b.append("yammerMessagesLiked=");
        b.append(this.yammerMessagesLiked);
        b.append(", ");
        b.append("reportDate=");
        b.append(this.reportDate);
        b.append(", ");
        b.append("reportPeriod=");
        b.append(this.reportPeriod);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/entity/Office365GroupsActivityCounts.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Long;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.time.LocalDate;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "exchangeEmailsReceived", 
    "reportDate", 
    "reportPeriod", 
    "reportRefreshDate", 
    "yammerMessagesLiked", 
    "yammerMessagesPosted", 
    "yammerMessagesRead"})
@JsonInclude(Include.NON_NULL)
public class Office365GroupsActivityCounts extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.office365GroupsActivityCounts";
    }

    @JsonProperty("exchangeEmailsReceived")
    protected Long exchangeEmailsReceived;

    @JsonProperty("reportDate")
    protected LocalDate reportDate;

    @JsonProperty("reportPeriod")
    protected String reportPeriod;

    @JsonProperty("reportRefreshDate")
    protected LocalDate reportRefreshDate;

    @JsonProperty("yammerMessagesLiked")
    protected Long yammerMessagesLiked;

    @JsonProperty("yammerMessagesPosted")
    protected Long yammerMessagesPosted;

    @JsonProperty("yammerMessagesRead")
    protected Long yammerMessagesRead;

    protected Office365GroupsActivityCounts() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderOffice365GroupsActivityCounts() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private Long exchangeEmailsReceived;
        private LocalDate reportDate;
        private String reportPeriod;
        private LocalDate reportRefreshDate;
        private Long yammerMessagesLiked;
        private Long yammerMessagesPosted;
        private Long yammerMessagesRead;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder exchangeEmailsReceived(Long exchangeEmailsReceived) {
            this.exchangeEmailsReceived = exchangeEmailsReceived;
            this.changedFields = changedFields.add("exchangeEmailsReceived");
            return this;
        }

        public Builder reportDate(LocalDate reportDate) {
            this.reportDate = reportDate;
            this.changedFields = changedFields.add("reportDate");
            return this;
        }

        public Builder reportPeriod(String reportPeriod) {
            this.reportPeriod = reportPeriod;
            this.changedFields = changedFields.add("reportPeriod");
            return this;
        }

        public Builder reportRefreshDate(LocalDate reportRefreshDate) {
            this.reportRefreshDate = reportRefreshDate;
            this.changedFields = changedFields.add("reportRefreshDate");
            return this;
        }

        public Builder yammerMessagesLiked(Long yammerMessagesLiked) {
            this.yammerMessagesLiked = yammerMessagesLiked;
            this.changedFields = changedFields.add("yammerMessagesLiked");
            return this;
        }

        public Builder yammerMessagesPosted(Long yammerMessagesPosted) {
            this.yammerMessagesPosted = yammerMessagesPosted;
            this.changedFields = changedFields.add("yammerMessagesPosted");
            return this;
        }

        public Builder yammerMessagesRead(Long yammerMessagesRead) {
            this.yammerMessagesRead = yammerMessagesRead;
            this.changedFields = changedFields.add("yammerMessagesRead");
            return this;
        }

        public Office365GroupsActivityCounts build() {
            Office365GroupsActivityCounts _x = new Office365GroupsActivityCounts();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.office365GroupsActivityCounts";
            _x.id = id;
            _x.exchangeEmailsReceived = exchangeEmailsReceived;
            _x.reportDate = reportDate;
            _x.reportPeriod = reportPeriod;
            _x.reportRefreshDate = reportRefreshDate;
            _x.yammerMessagesLiked = yammerMessagesLiked;
            _x.yammerMessagesPosted = yammerMessagesPosted;
            _x.yammerMessagesRead = yammerMessagesRead;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id, String.class));
        }
    }

    @Property(name="exchangeEmailsReceived")
    @JsonIgnore
    public Optional<Long> getExchangeEmailsReceived() {
        return Optional.ofNullable(exchangeEmailsReceived);
    }

    public Office365GroupsActivityCounts withExchangeEmailsReceived(Long exchangeEmailsReceived) {
        Office365GroupsActivityCounts _x = _copy();
        _x.changedFields = changedFields.add("exchangeEmailsReceived");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.office365GroupsActivityCounts");
        _x.exchangeEmailsReceived = exchangeEmailsReceived;
        return _x;
    }

    @Property(name="reportDate")
    @JsonIgnore
    public Optional<LocalDate> getReportDate() {
        return Optional.ofNullable(reportDate);
    }

    public Office365GroupsActivityCounts withReportDate(LocalDate reportDate) {
        Office365GroupsActivityCounts _x = _copy();
        _x.changedFields = changedFields.add("reportDate");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.office365GroupsActivityCounts");
        _x.reportDate = reportDate;
        return _x;
    }

    @Property(name="reportPeriod")
    @JsonIgnore
    public Optional<String> getReportPeriod() {
        return Optional.ofNullable(reportPeriod);
    }

    public Office365GroupsActivityCounts withReportPeriod(String reportPeriod) {
        Office365GroupsActivityCounts _x = _copy();
        _x.changedFields = changedFields.add("reportPeriod");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.office365GroupsActivityCounts");
        _x.reportPeriod = reportPeriod;
        return _x;
    }

    @Property(name="reportRefreshDate")
    @JsonIgnore
    public Optional<LocalDate> getReportRefreshDate() {
        return Optional.ofNullable(reportRefreshDate);
    }

    public Office365GroupsActivityCounts withReportRefreshDate(LocalDate reportRefreshDate) {
        Office365GroupsActivityCounts _x = _copy();
        _x.changedFields = changedFields.add("reportRefreshDate");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.office365GroupsActivityCounts");
        _x.reportRefreshDate = reportRefreshDate;
        return _x;
    }

    @Property(name="yammerMessagesLiked")
    @JsonIgnore
    public Optional<Long> getYammerMessagesLiked() {
        return Optional.ofNullable(yammerMessagesLiked);
    }

    public Office365GroupsActivityCounts withYammerMessagesLiked(Long yammerMessagesLiked) {
        Office365GroupsActivityCounts _x = _copy();
        _x.changedFields = changedFields.add("yammerMessagesLiked");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.office365GroupsActivityCounts");
        _x.yammerMessagesLiked = yammerMessagesLiked;
        return _x;
    }

    @Property(name="yammerMessagesPosted")
    @JsonIgnore
    public Optional<Long> getYammerMessagesPosted() {
        return Optional.ofNullable(yammerMessagesPosted);
    }

    public Office365GroupsActivityCounts withYammerMessagesPosted(Long yammerMessagesPosted) {
        Office365GroupsActivityCounts _x = _copy();
        _x.changedFields = changedFields.add("yammerMessagesPosted");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.office365GroupsActivityCounts");
        _x.yammerMessagesPosted = yammerMessagesPosted;
        return _x;
    }

    @Property(name="yammerMessagesRead")
    @JsonIgnore
    public Optional<Long> getYammerMessagesRead() {
        return Optional.ofNullable(yammerMessagesRead);
    }

    public Office365GroupsActivityCounts withYammerMessagesRead(Long yammerMessagesRead) {
        Office365GroupsActivityCounts _x = _copy();
        _x.changedFields = changedFields.add("yammerMessagesRead");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.office365GroupsActivityCounts");
        _x.yammerMessagesRead = yammerMessagesRead;
        return _x;
    }

    public Office365GroupsActivityCounts withUnmappedField(String name, Object value) {
        Office365GroupsActivityCounts _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public Office365GroupsActivityCounts patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        Office365GroupsActivityCounts _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public Office365GroupsActivityCounts put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        Office365GroupsActivityCounts _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private Office365GroupsActivityCounts _copy() {
        Office365GroupsActivityCounts _x = new Office365GroupsActivityCounts();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.id = id;
        _x.exchangeEmailsReceived = exchangeEmailsReceived;
        _x.reportDate = reportDate;
        _x.reportPeriod = reportPeriod;
        _x.reportRefreshDate = reportRefreshDate;
        _x.yammerMessagesLiked = yammerMessagesLiked;
        _x.yammerMessagesPosted = yammerMessagesPosted;
        _x.yammerMessagesRead = yammerMessagesRead;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("Office365GroupsActivityCounts[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("exchangeEmailsReceived=");
        b.append(this.exchangeEmailsReceived);
        b.append(", ");
        b.append("reportDate=");
        b.append(this.reportDate);
        b.append(", ");
        b.append("reportPeriod=");
        b.append(this.reportPeriod);
        b.append(", ");
        b.append("reportRefreshDate=");
        b.append(this.reportRefreshDate);
        b.append(", ");
        b.append("yammerMessagesLiked=");
        b.append(this.yammerMessagesLiked);
        b.append(", ");
        b.append("yammerMessagesPosted=");
        b.append(this.yammerMessagesPosted);
        b.append(", ");
        b.append("yammerMessagesRead=");
        b.append(this.yammerMessagesRead);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}
